/******************************************************************************
 *  rawgbf.h   - code for class 'RawGBF'- a module that reads raw text files:
 *		  ot and nt using indexs ??.bks ??.cps ??.vss
 *
 * $Id: rawgbf.h,v 1.5 2002/10/01 19:52:40 dglassey Exp $
 *
 * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
 *	CrossWire Bible Society
 *	P. O. Box 2528
 *	Tempe, AZ  85280-2528
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation version 2.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 */

#ifndef RAWGBF_H
#define RAWGBF_H

#include <rawverse.h>
#include <swtext.h>
#include <swfilter.h>

#include <defs.h>

SWORD_NAMESPACE_START

class SWDLLEXPORT RawGBF:public SWText, public RawVerse
{

public:
  
    
    RawGBF (const char *ipath, const char *iname = 0, const char *idesc =
	    0, SWDisplay * idisp = 0);
    virtual ~ RawGBF ();
  virtual operator char *();
};

SWORD_NAMESPACE_END
#endif
